@@ -1,7 +1,7 @@
 #
 #  This file is part of WebDyne.
 #
-#  This software is Copyright (c) 2016 by Andrew Speer <andrew@webdyne.org>.
+#  This software is Copyright (c) 2017 by Andrew Speer <andrew@webdyne.org>.
 #
 #  This is free software, licensed under:
 #
@@ -50,7 +50,7 @@ use WebDyne::Base;
 
 #  Version information
 #
-$VERSION='1.246';
+$VERSION='1.247';
 
 
 #  Debug load
@@ -67,6 +67,15 @@ our %CGI_Tag_Ucase=map {$_ => ucfirst($_)} (
 );
 
 
+#  Extend CGI with missing tags
+#
+our @CGI_Tag_Extend=(
+    
+    qw(Header)
+    
+);
+
+
 #  Get WebDyne and CGI tags from TreeBuilder module
 #
 *CGI_TAG_WEBDYNE=\%WebDyne::CGI_TAG_WEBDYNE;
@@ -500,6 +509,19 @@ sub compile_init {
     #0 && *CGI::end_html;
 
 
+    #  Extend CGI with any missing tags
+    #
+    if (UNIVERSAL::can(CGI, '_tag_func')) {
+        foreach my $tag (@CGI_Tag_Extend) {
+            *{"CGI::$tag"} = sub { return &CGI::_tag_func($tag,@_); };
+            foreach my $start_end ( qw/start end/ ) {
+                my $start_end_function = "${start_end}_${tag}";
+                *{"CGI::$start_end_function"} = sub { return &CGI::_tag_func($start_end_function,@_); };
+            }
+        }
+    }
+
+
     #  All done
     #
     return \undef;
